@@ -68,7 +68,7 @@ class FfmpegProcess:
             dynamic_ncols=True
         )
 
-        #progress_bar.clear()
+        progress_bar.clear()
         previous_seconds_processed = 0
 
         try:
@@ -77,8 +77,9 @@ class FfmpegProcess:
                 # out_time_ms=3505000
                 if "out_time_ms" in line:
                     seconds_processed = int(line[12:]) / 1000
+                    print(f"Processed: {seconds_processed}")
                     seconds_increase = seconds_processed - previous_seconds_processed
-                    print(seconds_increase)
+                    print(f"INCREASE: {seconds_increase}")
                     progress_bar.update(seconds_increase)
                     previous_seconds_processed = seconds_processed
         except KeyboardInterrupt:
